==> ogre-docs-1.10.4-4-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/class_ogre_1_1_g_l_state_cache_manager.js <==
var class_ogre_1_1_g_l_state_cache_manager =
[
    [ "GLStateCacheManager", "class_ogre_1_1_g_l_state_cache_manager.html#a58d232bfb0ce308d2ee20599fe811b4a", null ],
    [ "~GLStateCacheManager", "class_ogre_1_1_g_l_state_cache_manager.html#ab437989bdb74907ca0a2f9047f6cdc14", null ],
    [ "initializeCache", "class_ogre_1_1_g_l_state_cache_manager.html#ad43bce5a60133bf3e26b5cb85ea5780c", null ],
    [ "clearCache", "class_ogre_1_1_g_l_state_cache_manager.html#ae3647650b90330122a0463554c2197ed", null ],
    [ "bindGLBuffer", "class_ogre_1_1_g_l_state_cache_manager.html#a30f98b3d5fff15810d2ba6a50df72d2d", null ],
    [ "deleteGLBuffer", "class_ogre_1_1_g_l_state_cache_manager.html#a28e02b7e87709aa324da598b0aed73f1", null ],
    [ "bindGLTexture", "class_ogre_1_1_g_l_state_cache_manager.html#a2272f325aefeaed42a70402a885039db", null ],
    [ "invalidateStateForTexture", "class_ogre_1_1_g_l_state_cache_manager.html#a30b87f9d048645828c8d676c5c7b18f3", null ],
    [ "setTexParameteri", "class_ogre_1_1_g_l_state_cache_manager.html#ae415172ae054e8399e3552f12931b571", null ],
    [ "activateGLTextureUnit", "class_ogre_1_1_g_l_state_cache_manager.html#a503d7a019989e664319aeaf9623cae7f", null ],
    [ "getBlendEquation", "class_ogre_1_1_g_l_state_cache_manager.html#a68f462a1e4472a470d3f07c242d38b17", null ],
    [ "setBlendEquation", "class_ogre_1_1_g_l_state_cache_manager.html#ae9b59e1ecd6b8caace258a2cfc2e0a44", null ],
    [ "setBlendEquation", "class_ogre_1_1_g_l_state_cache_manager.html#a3d358bd2e292de56c13bef4305102703", null ],
    [ "setBlendFunc", "class_ogre_1_1_g_l_state_cache_manager.html#ac41728d731d51c3a0565ddcc5deafbba", null ],
    [ "setShadeModel", "class_ogre_1_1_g_l_state_cache_manager.html#aa1dc4e26334a3036443a6b62307c4f0c", null ],
    [ "setLightAmbient", "class_ogre_1_1_g_l_state_cache_manager.html#a47e50634abd2d7703451011237a949f3", null ],
    [ "getDepthMask", "class_ogre_1_1_g_l_state_cache_manager.html#a5cb39d255cc3f2fafe9b525a4a2a14ef", null ],
    [ "setDepthMask", "class_ogre_1_1_g_l_state_cache_manager.html#a93122a5b320fddf5302ab92a61f81b8d", null ],
    [ "getDepthFunc", "class_ogre_1_1_g_l_state_cache_manager.html#a8a4e3351218b93df1ebd957feb432ed5", null ],
    [ "setDepthFunc", "class_ogre_1_1_g_l_state_cache_manager.html#af33ee469391043129536d347a8bbe4e9", null ],
    [ "getClearDepth", "class_ogre_1_1_g_l_state_cache_manager.html#a5399298a93e3655c504914f0d7bd5380", null ],
    [ "setClearDepth", "class_ogre_1_1_g_l_state_cache_manager.html#a925e90ec802384a5981005db7a341188", null ],
    [ "setClearColour", "class_ogre_1_1_g_l_state_cache_manager.html#a7114118a5d4f6615cc8c1ad89a867033", null ],
    [ "getColourMask", "class_ogre_1_1_g_l_state_cache_manager.html#a87a3b13db7f57487b68407ad1e7efa7d", null ],
    [ "setColourMask", "class_ogre_1_1_g_l_state_cache_manager.html#afa73f5191063f144f39a2a2eb271c5e9", null ],
    [ "getStencilMask", "class_ogre_1_1_g_l_state_cache_manager.html#abbe3610468ea14aea26022bb3cd72ad2", null ],
    [ "setStencilMask", "class_ogre_1_1_g_l_state_cache_manager.html#ab18b876a5913be25bbe48cb436e0c719", null ],
    [ "setEnabled", "class_ogre_1_1_g_l_state_cache_manager.html#a8979e6b4ffd2066c1a284865cda24195", null ],
    [ "getDiscardBuffers", "class_ogre_1_1_g_l_state_cache_manager.html#a6f0d45dd814d2cebe78a3b94250d8b48", null ],
    [ "setDiscardBuffers", "class_ogre_1_1_g_l_state_cache_manager.html#a1280ab4d340af508ea63d7c64f482ccc", null ],
    [ "getPolygonMode", "class_ogre_1_1_g_l_state_cache_manager.html#a95340eac24b828a0ca6b474f8200153c", null ],
    [ "setPolygonMode", "class_ogre_1_1_g_l_state_cache_manager.html#a3fea365e60b4d00b5170f4680e43a890", null ],
    [ "getCullFace", "class_ogre_1_1_g_l_state_cache_manager.html#a6fbb8ac33d155528f776a3466de0f8cb", null ],
    [ "setCullFace", "class_ogre_1_1_g_l_state_cache_manager.html#a760ef0b0efc4c36f08187a17a4db9b5f", null ],
    [ "enableTextureCoordGen", "class_ogre_1_1_g_l_state_cache_manager.html#a4a74ad977c24cf7d7a3f4b2e6bd821ad", null ],
    [ "disableTextureCoordGen", "class_ogre_1_1_g_l_state_cache_manager.html#a0eb2ad7bc3687df2c75ecdd5f284d8b8", null ],
    [ "setMaterialAmbient", "class_ogre_1_1_g_l_state_cache_manager.html#acd35984db19f7b0d3e102ba46245d678", null ],
    [ "setMaterialDiffuse", "class_ogre_1_1_g_l_state_cache_manager.html#a720cf2a5d62d26258dd6666b40b1f973", null ],
    [ "setMaterialEmissive", "class_ogre_1_1_g_l_state_cache_manager.html#a4f291fa502b849caf497aae8f0daa793", null ],
    [ "setMaterialSpecular", "class_ogre_1_1_g_l_state_cache_manager.html#a2027c9c78f2f532ca26e73f98389a2dd", null ],
    [ "setMaterialShininess", "class_ogre_1_1_g_l_state_cache_manager.html#a205ab692edbd49198dc4a41d225c6098", null ],
    [ "setPointSize", "class_ogre_1_1_g_l_state_cache_manager.html#a516ab7a10afd1a0cb4b8575cab288091", null ],
    [ "setPointParameters", "class_ogre_1_1_g_l_state_cache_manager.html#a1159c7bd2ce8e85b90cb3058a36bda38", null ],
    [ "setViewport", "class_ogre_1_1_g_l_state_cache_manager.html#a4747c71f1dcca6a38ccf1722ce7d6e7e", null ],
    [ "getViewport", "class_ogre_1_1_g_l_state_cache_manager.html#af4cd9b59b9e3c9f0708f93a0097bbb46", null ]
];

==> ogre-docs-1.10.11-2-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/class_ogre_1_1_g_l_state_cache_manager.js <==
var class_ogre_1_1_g_l_state_cache_manager =
[
    [ "GLStateCacheManager", "class_ogre_1_1_g_l_state_cache_manager.html#a58d232bfb0ce308d2ee20599fe811b4a", null ],
    [ "initializeCache", "class_ogre_1_1_g_l_state_cache_manager.html#ad43bce5a60133bf3e26b5cb85ea5780c", null ],
    [ "clearCache", "class_ogre_1_1_g_l_state_cache_manager.html#ae3647650b90330122a0463554c2197ed", null ],
    [ "bindGLBuffer", "class_ogre_1_1_g_l_state_cache_manager.html#a30f98b3d5fff15810d2ba6a50df72d2d", null ],
    [ "deleteGLBuffer", "class_ogre_1_1_g_l_state_cache_manager.html#ab415f3f8323d19e0f053e23077b69c8d", null ],
    [ "bindGLTexture", "class_ogre_1_1_g_l_state_cache_manager.html#a2272f325aefeaed42a70402a885039db", null ],
    [ "invalidateStateForTexture", "class_ogre_1_1_g_l_state_cache_manager.html#a30b87f9d048645828c8d676c5c7b18f3", null ],
    [ "setTexParameteri", "class_ogre_1_1_g_l_state_cache_manager.html#ae415172ae054e8399e3552f12931b571", null ],
    [ "activateGLTextureUnit", "class_ogre_1_1_g_l_state_cache_manager.html#a503d7a019989e664319aeaf9623cae7f", null ],
    [ "setBlendEquation", "class_ogre_1_1_g_l_state_cache_manager.html#ae9b59e1ecd6b8caace258a2cfc2e0a44", null ],
    [ "setBlendEquation", "class_ogre_1_1_g_l_state_cache_manager.html#a3d358bd2e292de56c13bef4305102703", null ],
    [ "setBlendFunc", "class_ogre_1_1_g_l_state_cache_manager.html#ac41728d731d51c3a0565ddcc5deafbba", null ],
    [ "setShadeModel", "class_ogre_1_1_g_l_state_cache_manager.html#aa1dc4e26334a3036443a6b62307c4f0c", null ],
    [ "setLightAmbient", "class_ogre_1_1_g_l_state_cache_manager.html#a47e50634abd2d7703451011237a949f3", null ],
    [ "setDepthMask", "class_ogre_1_1_g_l_state_cache_manager.html#a93122a5b320fddf5302ab92a61f81b8d", null ],
    [ "getDepthFunc", "class_ogre_1_1_g_l_state_cache_manager.html#a8a4e3351218b93df1ebd957feb432ed5", null ],
    [ "setDepthFunc", "class_ogre_1_1_g_l_state_cache_manager.html#af33ee469391043129536d347a8bbe4e9", null ],
    [ "getClearDepth", "class_ogre_1_1_g_l_state_cache_manager.html#a5399298a93e3655c504914f0d7bd5380", null ],
    [ "setClearDepth", "class_ogre_1_1_g_l_state_cache_manager.html#a925e90ec802384a5981005db7a341188", null ],
    [ "setClearColour", "class_ogre_1_1_g_l_state_cache_manager.html#a7114118a5d4f6615cc8c1ad89a867033", null ],
    [ "setColourMask", "class_ogre_1_1_g_l_state_cache_manager.html#afa73f5191063f144f39a2a2eb271c5e9", null ],
    [ "setStencilMask", "class_ogre_1_1_g_l_state_cache_manager.html#ab18b876a5913be25bbe48cb436e0c719", null ],
    [ "setEnabled", "class_ogre_1_1_g_l_state_cache_manager.html#a8979e6b4ffd2066c1a284865cda24195", null ],
    [ "getPolygonMode", "class_ogre_1_1_g_l_state_cache_manager.html#a95340eac24b828a0ca6b474f8200153c", null ],
    [ "setPolygonMode", "class_ogre_1_1_g_l_state_cache_manager.html#a3fea365e60b4d00b5170f4680e43a890", null ],
    [ "getCullFace", "class_ogre_1_1_g_l_state_cache_manager.html#a6fbb8ac33d155528f776a3466de0f8cb", null ],
    [ "setCullFace", "class_ogre_1_1_g_l_state_cache_manager.html#a760ef0b0efc4c36f08187a17a4db9b5f", null ],
    [ "enableTextureCoordGen", "class_ogre_1_1_g_l_state_cache_manager.html#a4a74ad977c24cf7d7a3f4b2e6bd821ad", null ],
    [ "disableTextureCoordGen", "class_ogre_1_1_g_l_state_cache_manager.html#a0eb2ad7bc3687df2c75ecdd5f284d8b8", null ],
    [ "setMaterialAmbient", "class_ogre_1_1_g_l_state_cache_manager.html#acd35984db19f7b0d3e102ba46245d678", null ],
    [ "setMaterialDiffuse", "class_ogre_1_1_g_l_state_cache_manager.html#a720cf2a5d62d26258dd6666b40b1f973", null ],
    [ "setMaterialEmissive", "class_ogre_1_1_g_l_state_cache_manager.html#a4f291fa502b849caf497aae8f0daa793", null ],
    [ "setMaterialSpecular", "class_ogre_1_1_g_l_state_cache_manager.html#a2027c9c78f2f532ca26e73f98389a2dd", null ],
    [ "setMaterialShininess", "class_ogre_1_1_g_l_state_cache_manager.html#a205ab692edbd49198dc4a41d225c6098", null ],
    [ "setPointSize", "class_ogre_1_1_g_l_state_cache_manager.html#a516ab7a10afd1a0cb4b8575cab288091", null ],
    [ "setPointParameters", "class_ogre_1_1_g_l_state_cache_manager.html#a1159c7bd2ce8e85b90cb3058a36bda38", null ],
    [ "setViewport", "class_ogre_1_1_g_l_state_cache_manager.html#a4747c71f1dcca6a38ccf1722ce7d6e7e", null ],
    [ "getViewport", "class_ogre_1_1_g_l_state_cache_manager.html#a8cf8ecd02d3f7d9ecbda6decdabc09d8", null ],
    [ "getColourMask", "class_ogre_1_1_g_l_state_cache_manager.html#aed0a1810279e037e0c7b12f9ffc0c65e", null ],
    [ "getDepthMask", "class_ogre_1_1_g_l_state_cache_manager.html#a6176362b2fcb20cccafc9821951778ee", null ],
    [ "getStencilMask", "class_ogre_1_1_g_l_state_cache_manager.html#a01d78d20763464f69a157b0c81ba454f", null ]
];
